Documentation
¶
Overview ¶
Package queue implements the ordering logic to execute tensile.Node.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Queue ¶
type Queue struct {
// contains filtered or unexported fields
}
Queue aggregates tensile.Node and then orders them based on their dependencies for execution.
func (*Queue) Build ¶
Build returns the nodes in the queue in the order they should be executed. If there is a cycle in the graph, an error is returned.
type Work ¶
type Work struct {
// contains filtered or unexported fields
}
Work is the result of building a queue.
Click to show internal directories.
Click to hide internal directories.